AclConfigurationBuilder

Struct AclConfigurationBuilder 

#[non_exhaustive]
pub struct AclConfigurationBuilder { /* private fields */ }
A builder for AclConfiguration.

Implementations

Source

impl AclConfigurationBuilder

pub fn s3_acl_option(self, input: S3AclOption) -> Self

The Amazon S3 canned ACL that Athena should specify when storing query results, including data files inserted by Athena as the result of statements like CTAS or INSERT INTO. Currently the only supported canned ACL is BUCKET_OWNER_FULL_CONTROL. If a query runs in a workgroup and the workgroup overrides client-side settings, then the Amazon S3 canned ACL specified in the workgroup's settings is used for all queries that run in the workgroup. For more information about Amazon S3 canned ACLs, see Canned ACL in the Amazon S3 User Guide.

This field is required.
pub fn set_s3_acl_option(self, input: Option<S3AclOption>) -> Self

The Amazon S3 canned ACL that Athena should specify when storing query results, including data files inserted by Athena as the result of statements like CTAS or INSERT INTO. Currently the only supported canned ACL is BUCKET_OWNER_FULL_CONTROL. If a query runs in a workgroup and the workgroup overrides client-side settings, then the Amazon S3 canned ACL specified in the workgroup's settings is used for all queries that run in the workgroup. For more information about Amazon S3 canned ACLs, see Canned ACL in the Amazon S3 User Guide.

pub fn get_s3_acl_option(&self) -> &Option<S3AclOption>

The Amazon S3 canned ACL that Athena should specify when storing query results, including data files inserted by Athena as the result of statements like CTAS or INSERT INTO. Currently the only supported canned ACL is BUCKET_OWNER_FULL_CONTROL. If a query runs in a workgroup and the workgroup overrides client-side settings, then the Amazon S3 canned ACL specified in the workgroup's settings is used for all queries that run in the workgroup. For more information about Amazon S3 canned ACLs, see Canned ACL in the Amazon S3 User Guide.

pub fn build(self) -> Result<AclConfiguration, BuildError>

Consumes the builder and constructs a AclConfiguration. This method will fail if any of the following fields are not set: