#[non_exhaustive]pub struct AthenaErrorBuilder { /* private fields */ }Expand description
A builder for AthenaError.
Implementations
Sourceimpl AthenaErrorBuilder
impl AthenaErrorBuilder
Sourcepub fn error_category(self, input: i32) -> Self
pub fn error_category(self, input: i32) -> Self
An integer value that specifies the category of a query failure error. The following list shows the category for each integer value.
1 - System
2 - User
3 - Other
Sourcepub fn set_error_category(self, input: Option<i32>) -> Self
pub fn set_error_category(self, input: Option<i32>) -> Self
An integer value that specifies the category of a query failure error. The following list shows the category for each integer value.
1 - System
2 - User
3 - Other
Sourcepub fn get_error_category(&self) -> &Option<i32>
pub fn get_error_category(&self) -> &Option<i32>
An integer value that specifies the category of a query failure error. The following list shows the category for each integer value.
1 - System
2 - User
3 - Other
Sourcepub fn error_type(self, input: i32) -> Self
pub fn error_type(self, input: i32) -> Self
An integer value that provides specific information about an Athena query error. For the meaning of specific values, see the Error Type Reference in the Amazon Athena User Guide.
Sourcepub fn set_error_type(self, input: Option<i32>) -> Self
pub fn set_error_type(self, input: Option<i32>) -> Self
An integer value that provides specific information about an Athena query error. For the meaning of specific values, see the Error Type Reference in the Amazon Athena User Guide.
Sourcepub fn get_error_type(&self) -> &Option<i32>
pub fn get_error_type(&self) -> &Option<i32>
An integer value that provides specific information about an Athena query error. For the meaning of specific values, see the Error Type Reference in the Amazon Athena User Guide.
Sourcepub fn set_retryable(self, input: Option<bool>) -> Self
pub fn set_retryable(self, input: Option<bool>) -> Self
True if the query might succeed if resubmitted.
Sourcepub fn get_retryable(&self) -> &Option<bool>
pub fn get_retryable(&self) -> &Option<bool>
True if the query might succeed if resubmitted.
Sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
Contains a short description of the error that occurred.
Sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
Contains a short description of the error that occurred.
Sourcepub fn get_error_message(&self) -> &Option<String>
pub fn get_error_message(&self) -> &Option<String>
Contains a short description of the error that occurred.
Sourcepub fn build(self) -> AthenaError
pub fn build(self) -> AthenaError
Consumes the builder and constructs a AthenaError.