#[non_exhaustive]pub struct CapacityAllocationBuilder { /* private fields */ }Expand description
A builder for CapacityAllocation.
Implementations
Sourceimpl CapacityAllocationBuilder
impl CapacityAllocationBuilder
Sourcepub fn status(self, input: CapacityAllocationStatus) -> Self
pub fn status(self, input: CapacityAllocationStatus) -> Self
The status of the capacity allocation.
This field is required.Sourcepub fn set_status(self, input: Option<CapacityAllocationStatus>) -> Self
pub fn set_status(self, input: Option<CapacityAllocationStatus>) -> Self
The status of the capacity allocation.
Sourcepub fn get_status(&self) -> &Option<CapacityAllocationStatus>
pub fn get_status(&self) -> &Option<CapacityAllocationStatus>
The status of the capacity allocation.
Sourcepub fn status_message(self, input: impl Into<String>) -> Self
pub fn status_message(self, input: impl Into<String>) -> Self
The status message of the capacity allocation.
Sourcepub fn set_status_message(self, input: Option<String>) -> Self
pub fn set_status_message(self, input: Option<String>) -> Self
The status message of the capacity allocation.
Sourcepub fn get_status_message(&self) -> &Option<String>
pub fn get_status_message(&self) -> &Option<String>
The status message of the capacity allocation.
Sourcepub fn request_time(self, input: DateTime) -> Self
pub fn request_time(self, input: DateTime) -> Self
The time when the capacity allocation was requested.
This field is required.Sourcepub fn set_request_time(self, input: Option<DateTime>) -> Self
pub fn set_request_time(self, input: Option<DateTime>) -> Self
The time when the capacity allocation was requested.
Sourcepub fn get_request_time(&self) -> &Option<DateTime>
pub fn get_request_time(&self) -> &Option<DateTime>
The time when the capacity allocation was requested.
Sourcepub fn request_completion_time(self, input: DateTime) -> Self
pub fn request_completion_time(self, input: DateTime) -> Self
The time when the capacity allocation request was completed.
Sourcepub fn set_request_completion_time(self, input: Option<DateTime>) -> Self
pub fn set_request_completion_time(self, input: Option<DateTime>) -> Self
The time when the capacity allocation request was completed.
Sourcepub fn get_request_completion_time(&self) -> &Option<DateTime>
pub fn get_request_completion_time(&self) -> &Option<DateTime>
The time when the capacity allocation request was completed.
Sourcepub fn build(self) -> Result<CapacityAllocation, BuildError>
pub fn build(self) -> Result<CapacityAllocation, BuildError>
Consumes the builder and constructs a CapacityAllocation.
This method will fail if any of the following fields are not set: