#[non_exhaustive]pub struct CapacityReservationBuilder { /* private fields */ }Expand description
A builder for CapacityReservation.
Implementations
Sourceimpl CapacityReservationBuilder
impl CapacityReservationBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the capacity reservation.
This field is required.Sourcepub fn status(self, input: CapacityReservationStatus) -> Self
pub fn status(self, input: CapacityReservationStatus) -> Self
The status of the capacity reservation.
This field is required.Sourcepub fn set_status(self, input: Option<CapacityReservationStatus>) -> Self
pub fn set_status(self, input: Option<CapacityReservationStatus>) -> Self
The status of the capacity reservation.
Sourcepub fn get_status(&self) -> &Option<CapacityReservationStatus>
pub fn get_status(&self) -> &Option<CapacityReservationStatus>
The status of the capacity reservation.
Sourcepub fn target_dpus(self, input: i32) -> Self
pub fn target_dpus(self, input: i32) -> Self
The number of data processing units requested.
This field is required.Sourcepub fn set_target_dpus(self, input: Option<i32>) -> Self
pub fn set_target_dpus(self, input: Option<i32>) -> Self
The number of data processing units requested.
Sourcepub fn get_target_dpus(&self) -> &Option<i32>
pub fn get_target_dpus(&self) -> &Option<i32>
The number of data processing units requested.
Sourcepub fn allocated_dpus(self, input: i32) -> Self
pub fn allocated_dpus(self, input: i32) -> Self
The number of data processing units currently allocated.
This field is required.Sourcepub fn set_allocated_dpus(self, input: Option<i32>) -> Self
pub fn set_allocated_dpus(self, input: Option<i32>) -> Self
The number of data processing units currently allocated.
Sourcepub fn get_allocated_dpus(&self) -> &Option<i32>
pub fn get_allocated_dpus(&self) -> &Option<i32>
The number of data processing units currently allocated.
Sourcepub fn last_allocation(self, input: CapacityAllocation) -> Self
pub fn last_allocation(self, input: CapacityAllocation) -> Self
Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
Sourcepub fn set_last_allocation(self, input: Option<CapacityAllocation>) -> Self
pub fn set_last_allocation(self, input: Option<CapacityAllocation>) -> Self
Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
Sourcepub fn get_last_allocation(&self) -> &Option<CapacityAllocation>
pub fn get_last_allocation(&self) -> &Option<CapacityAllocation>
Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
Sourcepub fn last_successful_allocation_time(self, input: DateTime) -> Self
pub fn last_successful_allocation_time(self, input: DateTime) -> Self
The time of the most recent capacity allocation that succeeded.
Sourcepub fn set_last_successful_allocation_time(
self,
input: Option<DateTime>,
) -> Self
pub fn set_last_successful_allocation_time( self, input: Option<DateTime>, ) -> Self
The time of the most recent capacity allocation that succeeded.
Sourcepub fn get_last_successful_allocation_time(&self) -> &Option<DateTime>
pub fn get_last_successful_allocation_time(&self) -> &Option<DateTime>
The time of the most recent capacity allocation that succeeded.
Sourcepub fn creation_time(self, input: DateTime) -> Self
pub fn creation_time(self, input: DateTime) -> Self
The time in UTC epoch millis when the capacity reservation was created.
This field is required.Sourcepub fn set_creation_time(self, input: Option<DateTime>) -> Self
pub fn set_creation_time(self, input: Option<DateTime>) -> Self
The time in UTC epoch millis when the capacity reservation was created.
Sourcepub fn get_creation_time(&self) -> &Option<DateTime>
pub fn get_creation_time(&self) -> &Option<DateTime>
The time in UTC epoch millis when the capacity reservation was created.
Sourcepub fn build(self) -> Result<CapacityReservation, BuildError>
pub fn build(self) -> Result<CapacityReservation, BuildError>
Consumes the builder and constructs a CapacityReservation.
This method will fail if any of the following fields are not set: