#[non_exhaustive]pub struct ClassificationBuilder { /* private fields */ }Expand description
A builder for Classification.
Implementations
Sourceimpl ClassificationBuilder
impl ClassificationBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the configuration classification.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the configuration classification.
Sourcepub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to properties.
To override the contents of this collection use set_properties.
A set of properties specified within a configuration classification.
Sourcepub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
A set of properties specified within a configuration classification.
Sourcepub fn get_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_properties(&self) -> &Option<HashMap<String, String>>
A set of properties specified within a configuration classification.
Sourcepub fn build(self) -> Classification
pub fn build(self) -> Classification
Consumes the builder and constructs a Classification.