#[non_exhaustive]pub struct ColumnInfoBuilder { /* private fields */ }Expand description
A builder for ColumnInfo.
Implementations
Sourceimpl ColumnInfoBuilder
impl ColumnInfoBuilder
Sourcepub fn catalog_name(self, input: impl Into<String>) -> Self
pub fn catalog_name(self, input: impl Into<String>) -> Self
The catalog to which the query results belong.
Sourcepub fn set_catalog_name(self, input: Option<String>) -> Self
pub fn set_catalog_name(self, input: Option<String>) -> Self
The catalog to which the query results belong.
Sourcepub fn get_catalog_name(&self) -> &Option<String>
pub fn get_catalog_name(&self) -> &Option<String>
The catalog to which the query results belong.
Sourcepub fn schema_name(self, input: impl Into<String>) -> Self
pub fn schema_name(self, input: impl Into<String>) -> Self
The schema name (database name) to which the query results belong.
Sourcepub fn set_schema_name(self, input: Option<String>) -> Self
pub fn set_schema_name(self, input: Option<String>) -> Self
The schema name (database name) to which the query results belong.
Sourcepub fn get_schema_name(&self) -> &Option<String>
pub fn get_schema_name(&self) -> &Option<String>
The schema name (database name) to which the query results belong.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The table name for the query results.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The table name for the query results.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The table name for the query results.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the column.
This field is required.Sourcepub fn type(self, input: impl Into<String>) -> Self
pub fn type(self, input: impl Into<String>) -> Self
The data type of the column.
This field is required.Sourcepub fn precision(self, input: i32) -> Self
pub fn precision(self, input: i32) -> Self
For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.
Sourcepub fn set_precision(self, input: Option<i32>) -> Self
pub fn set_precision(self, input: Option<i32>) -> Self
For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.
Sourcepub fn get_precision(&self) -> &Option<i32>
pub fn get_precision(&self) -> &Option<i32>
For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.
Sourcepub fn scale(self, input: i32) -> Self
pub fn scale(self, input: i32) -> Self
For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.
Sourcepub fn set_scale(self, input: Option<i32>) -> Self
pub fn set_scale(self, input: Option<i32>) -> Self
For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.
Sourcepub fn get_scale(&self) -> &Option<i32>
pub fn get_scale(&self) -> &Option<i32>
For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.
Sourcepub fn nullable(self, input: ColumnNullable) -> Self
pub fn nullable(self, input: ColumnNullable) -> Self
Unsupported constraint. This value always shows as UNKNOWN.
Sourcepub fn set_nullable(self, input: Option<ColumnNullable>) -> Self
pub fn set_nullable(self, input: Option<ColumnNullable>) -> Self
Unsupported constraint. This value always shows as UNKNOWN.
Sourcepub fn get_nullable(&self) -> &Option<ColumnNullable>
pub fn get_nullable(&self) -> &Option<ColumnNullable>
Unsupported constraint. This value always shows as UNKNOWN.
Sourcepub fn case_sensitive(self, input: bool) -> Self
pub fn case_sensitive(self, input: bool) -> Self
Indicates whether values in the column are case-sensitive.
Sourcepub fn set_case_sensitive(self, input: Option<bool>) -> Self
pub fn set_case_sensitive(self, input: Option<bool>) -> Self
Indicates whether values in the column are case-sensitive.
Sourcepub fn get_case_sensitive(&self) -> &Option<bool>
pub fn get_case_sensitive(&self) -> &Option<bool>
Indicates whether values in the column are case-sensitive.
Sourcepub fn build(self) -> Result<ColumnInfo, BuildError>
pub fn build(self) -> Result<ColumnInfo, BuildError>
Consumes the builder and constructs a ColumnInfo.
This method will fail if any of the following fields are not set: