ExecutorsSummaryBuilder

Struct ExecutorsSummaryBuilder 

#[non_exhaustive]
pub struct ExecutorsSummaryBuilder { /* private fields */ }
A builder for ExecutorsSummary.

Implementations

Source

impl ExecutorsSummaryBuilder

pub fn executor_id(self, input: impl Into<String>) -> Self

The UUID of the executor.

This field is required.
pub fn set_executor_id(self, input: Option<String>) -> Self

The UUID of the executor.

pub fn get_executor_id(&self) -> &Option<String>

The UUID of the executor.

pub fn executor_type(self, input: ExecutorType) -> Self

The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).

pub fn set_executor_type(self, input: Option<ExecutorType>) -> Self

The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).

pub fn get_executor_type(&self) -> &Option<ExecutorType>

The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).

pub fn start_date_time(self, input: i64) -> Self

The date and time that the executor started.

pub fn set_start_date_time(self, input: Option<i64>) -> Self

The date and time that the executor started.

pub fn get_start_date_time(&self) -> &Option<i64>

The date and time that the executor started.

pub fn termination_date_time(self, input: i64) -> Self

The date and time that the executor was terminated.

pub fn set_termination_date_time(self, input: Option<i64>) -> Self

The date and time that the executor was terminated.

pub fn get_termination_date_time(&self) -> &Option<i64>

The date and time that the executor was terminated.

pub fn executor_state(self, input: ExecutorState) -> Self

The processing state of the executor. A description of each state follows.

CREATING - The executor is being started, including acquiring resources.

CREATED - The executor has been started.

REGISTERED - The executor has been registered.

TERMINATING - The executor is in the process of shutting down.

TERMINATED - The executor is no longer running.

FAILED - Due to a failure, the executor is no longer running.

pub fn set_executor_state(self, input: Option<ExecutorState>) -> Self

The processing state of the executor. A description of each state follows.

CREATING - The executor is being started, including acquiring resources.

CREATED - The executor has been started.

REGISTERED - The executor has been registered.

TERMINATING - The executor is in the process of shutting down.

TERMINATED - The executor is no longer running.

FAILED - Due to a failure, the executor is no longer running.

pub fn get_executor_state(&self) -> &Option<ExecutorState>

The processing state of the executor. A description of each state follows.

CREATING - The executor is being started, including acquiring resources.

CREATED - The executor has been started.

REGISTERED - The executor has been registered.

TERMINATING - The executor is in the process of shutting down.

TERMINATED - The executor is no longer running.

FAILED - Due to a failure, the executor is no longer running.

pub fn executor_size(self, input: i64) -> Self

The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.

pub fn set_executor_size(self, input: Option<i64>) -> Self

The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.

pub fn get_executor_size(&self) -> &Option<i64>

The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.

pub fn build(self) -> Result<ExecutorsSummary, BuildError>

Consumes the builder and constructs a ExecutorsSummary. This method will fail if any of the following fields are not set: