#[non_exhaustive]pub struct ManagedLoggingConfigurationBuilder { /* private fields */ }Expand description
A builder for ManagedLoggingConfiguration.
Implementations
Sourceimpl ManagedLoggingConfigurationBuilder
impl ManagedLoggingConfigurationBuilder
Sourcepub fn enabled(self, input: bool) -> Self
pub fn enabled(self, input: bool) -> Self
Enables mamanged log persistence.
This field is required.Sourcepub fn set_enabled(self, input: Option<bool>) -> Self
pub fn set_enabled(self, input: Option<bool>) -> Self
Enables mamanged log persistence.
Sourcepub fn get_enabled(&self) -> &Option<bool>
pub fn get_enabled(&self) -> &Option<bool>
Enables mamanged log persistence.
Sourcepub fn kms_key(self, input: impl Into<String>) -> Self
pub fn kms_key(self, input: impl Into<String>) -> Self
The KMS key ARN to encrypt the logs stored in managed log persistence.
Sourcepub fn set_kms_key(self, input: Option<String>) -> Self
pub fn set_kms_key(self, input: Option<String>) -> Self
The KMS key ARN to encrypt the logs stored in managed log persistence.
Sourcepub fn get_kms_key(&self) -> &Option<String>
pub fn get_kms_key(&self) -> &Option<String>
The KMS key ARN to encrypt the logs stored in managed log persistence.
Sourcepub fn build(self) -> Result<ManagedLoggingConfiguration, BuildError>
pub fn build(self) -> Result<ManagedLoggingConfiguration, BuildError>
Consumes the builder and constructs a ManagedLoggingConfiguration.
This method will fail if any of the following fields are not set: