ManagedQueryResultsConfigurationUpdatesBuilder

Struct ManagedQueryResultsConfigurationUpdatesBuilder 

#[non_exhaustive]
pub struct ManagedQueryResultsConfigurationUpdatesBuilder { /* private fields */ }
Implementations

Source

impl ManagedQueryResultsConfigurationUpdatesBuilder

pub fn enabled(self, input: bool) -> Self

If set to true, specifies that Athena manages query results in Athena owned storage.

pub fn set_enabled(self, input: Option<bool>) -> Self

If set to true, specifies that Athena manages query results in Athena owned storage.

pub fn get_enabled(&self) -> &Option<bool>

If set to true, specifies that Athena manages query results in Athena owned storage.

pub fn encryption_configuration( self, input: ManagedQueryResultsEncryptionConfiguration, ) -> Self

If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.

pub fn set_encryption_configuration( self, input: Option<ManagedQueryResultsEncryptionConfiguration>, ) -> Self

If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.

pub fn get_encryption_configuration( &self, ) -> &Option<ManagedQueryResultsEncryptionConfiguration>

If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.

pub fn remove_encryption_configuration(self, input: bool) -> Self

If set to true, it removes workgroup from Athena owned storage. The existing query results are cleaned up after 24hrs. You must provide query results in location specified under ResultConfiguration$OutputLocation.

pub fn set_remove_encryption_configuration(self, input: Option<bool>) -> Self

If set to true, it removes workgroup from Athena owned storage. The existing query results are cleaned up after 24hrs. You must provide query results in location specified under ResultConfiguration$OutputLocation.

pub fn get_remove_encryption_configuration(&self) -> &Option<bool>

If set to true, it removes workgroup from Athena owned storage. The existing query results are cleaned up after 24hrs. You must provide query results in location specified under ResultConfiguration$OutputLocation.

pub fn build(self) -> ManagedQueryResultsConfigurationUpdates

Consumes the builder and constructs a ManagedQueryResultsConfigurationUpdates.