#[non_exhaustive]pub struct PreparedStatementBuilder { /* private fields */ }Expand description
A builder for PreparedStatement.
Implementations
Sourceimpl PreparedStatementBuilder
impl PreparedStatementBuilder
Sourcepub fn statement_name(self, input: impl Into<String>) -> Self
pub fn statement_name(self, input: impl Into<String>) -> Self
The name of the prepared statement.
Sourcepub fn set_statement_name(self, input: Option<String>) -> Self
pub fn set_statement_name(self, input: Option<String>) -> Self
The name of the prepared statement.
Sourcepub fn get_statement_name(&self) -> &Option<String>
pub fn get_statement_name(&self) -> &Option<String>
The name of the prepared statement.
Sourcepub fn query_statement(self, input: impl Into<String>) -> Self
pub fn query_statement(self, input: impl Into<String>) -> Self
The query string for the prepared statement.
Sourcepub fn set_query_statement(self, input: Option<String>) -> Self
pub fn set_query_statement(self, input: Option<String>) -> Self
The query string for the prepared statement.
Sourcepub fn get_query_statement(&self) -> &Option<String>
pub fn get_query_statement(&self) -> &Option<String>
The query string for the prepared statement.
Sourcepub fn work_group_name(self, input: impl Into<String>) -> Self
pub fn work_group_name(self, input: impl Into<String>) -> Self
The name of the workgroup to which the prepared statement belongs.
Sourcepub fn set_work_group_name(self, input: Option<String>) -> Self
pub fn set_work_group_name(self, input: Option<String>) -> Self
The name of the workgroup to which the prepared statement belongs.
Sourcepub fn get_work_group_name(&self) -> &Option<String>
pub fn get_work_group_name(&self) -> &Option<String>
The name of the workgroup to which the prepared statement belongs.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the prepared statement.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the prepared statement.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the prepared statement.
Sourcepub fn last_modified_time(self, input: DateTime) -> Self
pub fn last_modified_time(self, input: DateTime) -> Self
The last modified time of the prepared statement.
Sourcepub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_time(self, input: Option<DateTime>) -> Self
The last modified time of the prepared statement.
Sourcepub fn get_last_modified_time(&self) -> &Option<DateTime>
pub fn get_last_modified_time(&self) -> &Option<DateTime>
The last modified time of the prepared statement.
Sourcepub fn build(self) -> PreparedStatement
pub fn build(self) -> PreparedStatement
Consumes the builder and constructs a PreparedStatement.