#[non_exhaustive]pub struct ResultReuseByAgeConfigurationBuilder { /* private fields */ }Expand description
A builder for ResultReuseByAgeConfiguration.
Implementations
Sourceimpl ResultReuseByAgeConfigurationBuilder
impl ResultReuseByAgeConfigurationBuilder
Sourcepub fn enabled(self, input: bool) -> Self
pub fn enabled(self, input: bool) -> Self
True if previous query results can be reused when the query is run; otherwise, false. The default is false.
This field is required.Sourcepub fn set_enabled(self, input: Option<bool>) -> Self
pub fn set_enabled(self, input: Option<bool>) -> Self
True if previous query results can be reused when the query is run; otherwise, false. The default is false.
Sourcepub fn get_enabled(&self) -> &Option<bool>
pub fn get_enabled(&self) -> &Option<bool>
True if previous query results can be reused when the query is run; otherwise, false. The default is false.
Sourcepub fn max_age_in_minutes(self, input: i32) -> Self
pub fn max_age_in_minutes(self, input: i32) -> Self
Specifies, in minutes, the maximum age of a previous query result that Athena should consider for reuse. The default is 60.
Sourcepub fn set_max_age_in_minutes(self, input: Option<i32>) -> Self
pub fn set_max_age_in_minutes(self, input: Option<i32>) -> Self
Specifies, in minutes, the maximum age of a previous query result that Athena should consider for reuse. The default is 60.
Sourcepub fn get_max_age_in_minutes(&self) -> &Option<i32>
pub fn get_max_age_in_minutes(&self) -> &Option<i32>
Specifies, in minutes, the maximum age of a previous query result that Athena should consider for reuse. The default is 60.
Sourcepub fn build(self) -> ResultReuseByAgeConfiguration
pub fn build(self) -> ResultReuseByAgeConfiguration
Consumes the builder and constructs a ResultReuseByAgeConfiguration.