#[non_exhaustive]pub struct ResultReuseInformationBuilder { /* private fields */ }Expand description
A builder for ResultReuseInformation.
Implementations
Sourceimpl ResultReuseInformationBuilder
impl ResultReuseInformationBuilder
Sourcepub fn reused_previous_result(self, input: bool) -> Self
pub fn reused_previous_result(self, input: bool) -> Self
True if a previous query result was reused; false if the result was generated from a new run of the query.
This field is required.Sourcepub fn set_reused_previous_result(self, input: Option<bool>) -> Self
pub fn set_reused_previous_result(self, input: Option<bool>) -> Self
True if a previous query result was reused; false if the result was generated from a new run of the query.
Sourcepub fn get_reused_previous_result(&self) -> &Option<bool>
pub fn get_reused_previous_result(&self) -> &Option<bool>
True if a previous query result was reused; false if the result was generated from a new run of the query.
Sourcepub fn build(self) -> ResultReuseInformation
pub fn build(self) -> ResultReuseInformation
Consumes the builder and constructs a ResultReuseInformation.