#[non_exhaustive]pub struct ResultSetBuilder { /* private fields */ }Expand description
A builder for ResultSet.
Implementations
Sourceimpl ResultSetBuilder
impl ResultSetBuilder
Sourcepub fn rows(self, input: Row) -> Self
pub fn rows(self, input: Row) -> Self
Appends an item to rows.
To override the contents of this collection use set_rows.
The rows in the table.
Sourcepub fn result_set_metadata(self, input: ResultSetMetadata) -> Self
pub fn result_set_metadata(self, input: ResultSetMetadata) -> Self
The metadata that describes the column structure and data types of a table of query results.
Sourcepub fn set_result_set_metadata(self, input: Option<ResultSetMetadata>) -> Self
pub fn set_result_set_metadata(self, input: Option<ResultSetMetadata>) -> Self
The metadata that describes the column structure and data types of a table of query results.
Sourcepub fn get_result_set_metadata(&self) -> &Option<ResultSetMetadata>
pub fn get_result_set_metadata(&self) -> &Option<ResultSetMetadata>
The metadata that describes the column structure and data types of a table of query results.