#[non_exhaustive]pub struct ResultSetMetadataBuilder { /* private fields */ }Expand description
A builder for ResultSetMetadata.
Implementations
Sourceimpl ResultSetMetadataBuilder
impl ResultSetMetadataBuilder
Sourcepub fn column_info(self, input: ColumnInfo) -> Self
pub fn column_info(self, input: ColumnInfo) -> Self
Appends an item to column_info.
To override the contents of this collection use set_column_info.
Information about the columns returned in a query result metadata.
Sourcepub fn set_column_info(self, input: Option<Vec<ColumnInfo>>) -> Self
pub fn set_column_info(self, input: Option<Vec<ColumnInfo>>) -> Self
Information about the columns returned in a query result metadata.
Sourcepub fn get_column_info(&self) -> &Option<Vec<ColumnInfo>>
pub fn get_column_info(&self) -> &Option<Vec<ColumnInfo>>
Information about the columns returned in a query result metadata.
Sourcepub fn build(self) -> ResultSetMetadata
pub fn build(self) -> ResultSetMetadata
Consumes the builder and constructs a ResultSetMetadata.