#[non_exhaustive]pub struct S3LoggingConfigurationBuilder { /* private fields */ }Expand description
A builder for S3LoggingConfiguration.
Implementations
Sourceimpl S3LoggingConfigurationBuilder
impl S3LoggingConfigurationBuilder
Sourcepub fn set_enabled(self, input: Option<bool>) -> Self
pub fn set_enabled(self, input: Option<bool>) -> Self
Enables S3 log delivery.
Sourcepub fn get_enabled(&self) -> &Option<bool>
pub fn get_enabled(&self) -> &Option<bool>
Enables S3 log delivery.
Sourcepub fn kms_key(self, input: impl Into<String>) -> Self
pub fn kms_key(self, input: impl Into<String>) -> Self
The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.
Sourcepub fn set_kms_key(self, input: Option<String>) -> Self
pub fn set_kms_key(self, input: Option<String>) -> Self
The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.
Sourcepub fn get_kms_key(&self) -> &Option<String>
pub fn get_kms_key(&self) -> &Option<String>
The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.
Sourcepub fn log_location(self, input: impl Into<String>) -> Self
pub fn log_location(self, input: impl Into<String>) -> Self
The Amazon S3 destination URI for log publishing.
Sourcepub fn set_log_location(self, input: Option<String>) -> Self
pub fn set_log_location(self, input: Option<String>) -> Self
The Amazon S3 destination URI for log publishing.
Sourcepub fn get_log_location(&self) -> &Option<String>
pub fn get_log_location(&self) -> &Option<String>
The Amazon S3 destination URI for log publishing.
Sourcepub fn build(self) -> Result<S3LoggingConfiguration, BuildError>
pub fn build(self) -> Result<S3LoggingConfiguration, BuildError>
Consumes the builder and constructs a S3LoggingConfiguration.
This method will fail if any of the following fields are not set: