#[non_exhaustive]pub struct SessionStatisticsBuilder { /* private fields */ }Expand description
A builder for SessionStatistics.
Implementations
Sourceimpl SessionStatisticsBuilder
impl SessionStatisticsBuilder
Sourcepub fn dpu_execution_in_millis(self, input: i64) -> Self
pub fn dpu_execution_in_millis(self, input: i64) -> Self
The data processing unit execution time for a session in milliseconds.
Sourcepub fn set_dpu_execution_in_millis(self, input: Option<i64>) -> Self
pub fn set_dpu_execution_in_millis(self, input: Option<i64>) -> Self
The data processing unit execution time for a session in milliseconds.
Sourcepub fn get_dpu_execution_in_millis(&self) -> &Option<i64>
pub fn get_dpu_execution_in_millis(&self) -> &Option<i64>
The data processing unit execution time for a session in milliseconds.
Sourcepub fn build(self) -> SessionStatistics
pub fn build(self) -> SessionStatistics
Consumes the builder and constructs a SessionStatistics.