#[non_exhaustive]pub struct SessionStatusBuilder { /* private fields */ }Expand description
A builder for SessionStatus.
Implementations
Sourceimpl SessionStatusBuilder
impl SessionStatusBuilder
Sourcepub fn start_date_time(self, input: DateTime) -> Self
pub fn start_date_time(self, input: DateTime) -> Self
The date and time that the session started.
Sourcepub fn set_start_date_time(self, input: Option<DateTime>) -> Self
pub fn set_start_date_time(self, input: Option<DateTime>) -> Self
The date and time that the session started.
Sourcepub fn get_start_date_time(&self) -> &Option<DateTime>
pub fn get_start_date_time(&self) -> &Option<DateTime>
The date and time that the session started.
Sourcepub fn last_modified_date_time(self, input: DateTime) -> Self
pub fn last_modified_date_time(self, input: DateTime) -> Self
The most recent date and time that the session was modified.
Sourcepub fn set_last_modified_date_time(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_date_time(self, input: Option<DateTime>) -> Self
The most recent date and time that the session was modified.
Sourcepub fn get_last_modified_date_time(&self) -> &Option<DateTime>
pub fn get_last_modified_date_time(&self) -> &Option<DateTime>
The most recent date and time that the session was modified.
Sourcepub fn end_date_time(self, input: DateTime) -> Self
pub fn end_date_time(self, input: DateTime) -> Self
The date and time that the session ended.
Sourcepub fn set_end_date_time(self, input: Option<DateTime>) -> Self
pub fn set_end_date_time(self, input: Option<DateTime>) -> Self
The date and time that the session ended.
Sourcepub fn get_end_date_time(&self) -> &Option<DateTime>
pub fn get_end_date_time(&self) -> &Option<DateTime>
The date and time that the session ended.
Sourcepub fn idle_since_date_time(self, input: DateTime) -> Self
pub fn idle_since_date_time(self, input: DateTime) -> Self
The date and time starting at which the session became idle. Can be empty if the session is not currently idle.
Sourcepub fn set_idle_since_date_time(self, input: Option<DateTime>) -> Self
pub fn set_idle_since_date_time(self, input: Option<DateTime>) -> Self
The date and time starting at which the session became idle. Can be empty if the session is not currently idle.
Sourcepub fn get_idle_since_date_time(&self) -> &Option<DateTime>
pub fn get_idle_since_date_time(&self) -> &Option<DateTime>
The date and time starting at which the session became idle. Can be empty if the session is not currently idle.
Sourcepub fn state(self, input: SessionState) -> Self
pub fn state(self, input: SessionState) -> Self
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn set_state(self, input: Option<SessionState>) -> Self
pub fn set_state(self, input: Option<SessionState>) -> Self
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn get_state(&self) -> &Option<SessionState>
pub fn get_state(&self) -> &Option<SessionState>
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn state_change_reason(self, input: impl Into<String>) -> Self
pub fn state_change_reason(self, input: impl Into<String>) -> Self
The reason for the session state change (for example, canceled because the session was terminated).
Sourcepub fn set_state_change_reason(self, input: Option<String>) -> Self
pub fn set_state_change_reason(self, input: Option<String>) -> Self
The reason for the session state change (for example, canceled because the session was terminated).
Sourcepub fn get_state_change_reason(&self) -> &Option<String>
pub fn get_state_change_reason(&self) -> &Option<String>
The reason for the session state change (for example, canceled because the session was terminated).
Sourcepub fn build(self) -> SessionStatus
pub fn build(self) -> SessionStatus
Consumes the builder and constructs a SessionStatus.