#[non_exhaustive]pub struct UnprocessedNamedQueryIdBuilder { /* private fields */ }Expand description
A builder for UnprocessedNamedQueryId.
Implementations
Sourceimpl UnprocessedNamedQueryIdBuilder
impl UnprocessedNamedQueryIdBuilder
Sourcepub fn named_query_id(self, input: impl Into<String>) -> Self
pub fn named_query_id(self, input: impl Into<String>) -> Self
The unique identifier of the named query.
Sourcepub fn set_named_query_id(self, input: Option<String>) -> Self
pub fn set_named_query_id(self, input: Option<String>) -> Self
The unique identifier of the named query.
Sourcepub fn get_named_query_id(&self) -> &Option<String>
pub fn get_named_query_id(&self) -> &Option<String>
The unique identifier of the named query.
Sourcepub fn error_code(self, input: impl Into<String>) -> Self
pub fn error_code(self, input: impl Into<String>) -> Self
The error code returned when the processing request for the named query failed, if applicable.
Sourcepub fn set_error_code(self, input: Option<String>) -> Self
pub fn set_error_code(self, input: Option<String>) -> Self
The error code returned when the processing request for the named query failed, if applicable.
Sourcepub fn get_error_code(&self) -> &Option<String>
pub fn get_error_code(&self) -> &Option<String>
The error code returned when the processing request for the named query failed, if applicable.
Sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
The error message returned when the processing request for the named query failed, if applicable.
Sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
The error message returned when the processing request for the named query failed, if applicable.
Sourcepub fn get_error_message(&self) -> &Option<String>
pub fn get_error_message(&self) -> &Option<String>
The error message returned when the processing request for the named query failed, if applicable.
Sourcepub fn build(self) -> UnprocessedNamedQueryId
pub fn build(self) -> UnprocessedNamedQueryId
Consumes the builder and constructs a UnprocessedNamedQueryId.