#[non_exhaustive]pub struct UnprocessedPreparedStatementNameBuilder { /* private fields */ }Expand description
A builder for UnprocessedPreparedStatementName.
Implementations
Sourceimpl UnprocessedPreparedStatementNameBuilder
impl UnprocessedPreparedStatementNameBuilder
Sourcepub fn statement_name(self, input: impl Into<String>) -> Self
pub fn statement_name(self, input: impl Into<String>) -> Self
The name of a prepared statement that could not be returned due to an error.
Sourcepub fn set_statement_name(self, input: Option<String>) -> Self
pub fn set_statement_name(self, input: Option<String>) -> Self
The name of a prepared statement that could not be returned due to an error.
Sourcepub fn get_statement_name(&self) -> &Option<String>
pub fn get_statement_name(&self) -> &Option<String>
The name of a prepared statement that could not be returned due to an error.
Sourcepub fn error_code(self, input: impl Into<String>) -> Self
pub fn error_code(self, input: impl Into<String>) -> Self
The error code returned when the request for the prepared statement failed.
Sourcepub fn set_error_code(self, input: Option<String>) -> Self
pub fn set_error_code(self, input: Option<String>) -> Self
The error code returned when the request for the prepared statement failed.
Sourcepub fn get_error_code(&self) -> &Option<String>
pub fn get_error_code(&self) -> &Option<String>
The error code returned when the request for the prepared statement failed.
Sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
The error message containing the reason why the prepared statement could not be returned. The following error messages are possible:
-
INVALID_INPUT- The name of the prepared statement that was provided is not valid (for example, the name is too long). -
STATEMENT_NOT_FOUND- A prepared statement with the name provided could not be found. -
UNAUTHORIZED- The requester does not have permission to access the workgroup that contains the prepared statement.
Sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
The error message containing the reason why the prepared statement could not be returned. The following error messages are possible:
-
INVALID_INPUT- The name of the prepared statement that was provided is not valid (for example, the name is too long). -
STATEMENT_NOT_FOUND- A prepared statement with the name provided could not be found. -
UNAUTHORIZED- The requester does not have permission to access the workgroup that contains the prepared statement.
Sourcepub fn get_error_message(&self) -> &Option<String>
pub fn get_error_message(&self) -> &Option<String>
The error message containing the reason why the prepared statement could not be returned. The following error messages are possible:
-
INVALID_INPUT- The name of the prepared statement that was provided is not valid (for example, the name is too long). -
STATEMENT_NOT_FOUND- A prepared statement with the name provided could not be found. -
UNAUTHORIZED- The requester does not have permission to access the workgroup that contains the prepared statement.
Sourcepub fn build(self) -> UnprocessedPreparedStatementName
pub fn build(self) -> UnprocessedPreparedStatementName
Consumes the builder and constructs a UnprocessedPreparedStatementName.