WorkGroupBuilder

Struct WorkGroupBuilder 

#[non_exhaustive]
pub struct WorkGroupBuilder { /* private fields */ }
A builder for WorkGroup.

Implementations

Source

impl WorkGroupBuilder

pub fn name(self, input: impl Into<String>) -> Self

The workgroup name.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The workgroup name.

pub fn get_name(&self) -> &Option<String>

The workgroup name.

pub fn state(self, input: WorkGroupState) -> Self

The state of the workgroup: ENABLED or DISABLED.

pub fn set_state(self, input: Option<WorkGroupState>) -> Self

The state of the workgroup: ENABLED or DISABLED.

pub fn get_state(&self) -> &Option<WorkGroupState>

The state of the workgroup: ENABLED or DISABLED.

pub fn configuration(self, input: WorkGroupConfiguration) -> Self

The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.

pub fn set_configuration(self, input: Option<WorkGroupConfiguration>) -> Self

The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.

pub fn get_configuration(&self) -> &Option<WorkGroupConfiguration>

The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.

pub fn description(self, input: impl Into<String>) -> Self

The workgroup description.

pub fn set_description(self, input: Option<String>) -> Self

The workgroup description.

pub fn get_description(&self) -> &Option<String>

The workgroup description.

pub fn creation_time(self, input: DateTime) -> Self

The date and time the workgroup was created.

pub fn set_creation_time(self, input: Option<DateTime>) -> Self

The date and time the workgroup was created.

pub fn get_creation_time(&self) -> &Option<DateTime>

The date and time the workgroup was created.

pub fn identity_center_application_arn(self, input: impl Into<String>) -> Self

The ARN of the IAM Identity Center enabled application associated with the workgroup.

pub fn set_identity_center_application_arn(self, input: Option<String>) -> Self

The ARN of the IAM Identity Center enabled application associated with the workgroup.

pub fn get_identity_center_application_arn(&self) -> &Option<String>

The ARN of the IAM Identity Center enabled application associated with the workgroup.

pub fn build(self) -> Result<WorkGroup, BuildError>

Consumes the builder and constructs a WorkGroup. This method will fail if any of the following fields are not set: