WorkGroupConfigurationBuilder

Struct WorkGroupConfigurationBuilder 

#[non_exhaustive]
pub struct WorkGroupConfigurationBuilder { /* private fields */ }
A builder for WorkGroupConfiguration.

Implementations

Source

impl WorkGroupConfigurationBuilder

pub fn result_configuration(self, input: ResultConfiguration) -> Self

The configuration for the workgroup, which includes the location in Amazon S3 where query and calculation results are stored and the encryption option, if any, used for query and calculation results. To run the query, you must specify the query results location using one of the ways: either in the workgroup using this setting, or for individual queries (client-side), using ResultConfiguration$OutputLocation. If none of them is set, Athena issues an error that no output location is provided.

pub fn set_result_configuration( self, input: Option<ResultConfiguration>, ) -> Self

The configuration for the workgroup, which includes the location in Amazon S3 where query and calculation results are stored and the encryption option, if any, used for query and calculation results. To run the query, you must specify the query results location using one of the ways: either in the workgroup using this setting, or for individual queries (client-side), using ResultConfiguration$OutputLocation. If none of them is set, Athena issues an error that no output location is provided.

pub fn get_result_configuration(&self) -> &Option<ResultConfiguration>

The configuration for the workgroup, which includes the location in Amazon S3 where query and calculation results are stored and the encryption option, if any, used for query and calculation results. To run the query, you must specify the query results location using one of the ways: either in the workgroup using this setting, or for individual queries (client-side), using ResultConfiguration$OutputLocation. If none of them is set, Athena issues an error that no output location is provided.

pub fn managed_query_results_configuration( self, input: ManagedQueryResultsConfiguration, ) -> Self

The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.

pub fn set_managed_query_results_configuration( self, input: Option<ManagedQueryResultsConfiguration>, ) -> Self

The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.

pub fn get_managed_query_results_configuration( &self, ) -> &Option<ManagedQueryResultsConfiguration>

The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.

pub fn enforce_work_group_configuration(self, input: bool) -> Self

If set to "true", the settings for the workgroup override client-side settings. If set to "false", client-side settings are used. This property is not required for Apache Spark enabled workgroups. For more information, see Workgroup Settings Override Client-Side Settings.

pub fn set_enforce_work_group_configuration(self, input: Option<bool>) -> Self

If set to "true", the settings for the workgroup override client-side settings. If set to "false", client-side settings are used. This property is not required for Apache Spark enabled workgroups. For more information, see Workgroup Settings Override Client-Side Settings.

pub fn get_enforce_work_group_configuration(&self) -> &Option<bool>

If set to "true", the settings for the workgroup override client-side settings. If set to "false", client-side settings are used. This property is not required for Apache Spark enabled workgroups. For more information, see Workgroup Settings Override Client-Side Settings.

pub fn publish_cloud_watch_metrics_enabled(self, input: bool) -> Self

Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.

pub fn set_publish_cloud_watch_metrics_enabled( self, input: Option<bool>, ) -> Self

Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.

pub fn get_publish_cloud_watch_metrics_enabled(&self) -> &Option<bool>

Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.

pub fn bytes_scanned_cutoff_per_query(self, input: i64) -> Self

The upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.

pub fn set_bytes_scanned_cutoff_per_query(self, input: Option<i64>) -> Self

The upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.

pub fn get_bytes_scanned_cutoff_per_query(&self) -> &Option<i64>

The upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.

pub fn requester_pays_enabled(self, input: bool) -> Self

If set to true, allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.

pub fn set_requester_pays_enabled(self, input: Option<bool>) -> Self

If set to true, allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.

pub fn get_requester_pays_enabled(&self) -> &Option<bool>

If set to true, allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.

pub fn engine_version(self, input: EngineVersion) -> Self

The engine version that all queries running on the workgroup use. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.

pub fn set_engine_version(self, input: Option<EngineVersion>) -> Self

The engine version that all queries running on the workgroup use. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.

pub fn get_engine_version(&self) -> &Option<EngineVersion>

The engine version that all queries running on the workgroup use. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.

pub fn additional_configuration(self, input: impl Into<String>) -> Self

Specifies a user defined JSON string that is passed to the notebook engine.

pub fn set_additional_configuration(self, input: Option<String>) -> Self

Specifies a user defined JSON string that is passed to the notebook engine.

pub fn get_additional_configuration(&self) -> &Option<String>

Specifies a user defined JSON string that is passed to the notebook engine.

pub fn execution_role(self, input: impl Into<String>) -> Self

The ARN of the execution role used to access user resources for Spark sessions and IAM Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and IAM Identity Center enabled workgroups. The property is required for IAM Identity Center enabled workgroups.

pub fn set_execution_role(self, input: Option<String>) -> Self

The ARN of the execution role used to access user resources for Spark sessions and IAM Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and IAM Identity Center enabled workgroups. The property is required for IAM Identity Center enabled workgroups.

pub fn get_execution_role(&self) -> &Option<String>

The ARN of the execution role used to access user resources for Spark sessions and IAM Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and IAM Identity Center enabled workgroups. The property is required for IAM Identity Center enabled workgroups.

pub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self

Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.

pub fn set_monitoring_configuration( self, input: Option<MonitoringConfiguration>, ) -> Self

Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.

pub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>

Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.

pub fn engine_configuration(self, input: EngineConfiguration) -> Self

The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).

To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.

pub fn set_engine_configuration( self, input: Option<EngineConfiguration>, ) -> Self

The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).

To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.

pub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>

The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).

To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.

pub fn customer_content_encryption_configuration( self, input: CustomerContentEncryptionConfiguration, ) -> Self

Specifies the KMS key that is used to encrypt the user's data stores in Athena. This setting does not apply to Athena SQL workgroups.

pub fn set_customer_content_encryption_configuration( self, input: Option<CustomerContentEncryptionConfiguration>, ) -> Self

Specifies the KMS key that is used to encrypt the user's data stores in Athena. This setting does not apply to Athena SQL workgroups.

pub fn get_customer_content_encryption_configuration( &self, ) -> &Option<CustomerContentEncryptionConfiguration>

Specifies the KMS key that is used to encrypt the user's data stores in Athena. This setting does not apply to Athena SQL workgroups.

pub fn enable_minimum_encryption_configuration(self, input: bool) -> Self

Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries.

The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.

pub fn set_enable_minimum_encryption_configuration( self, input: Option<bool>, ) -> Self

Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries.

The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.

pub fn get_enable_minimum_encryption_configuration(&self) -> &Option<bool>

Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries.

The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.

pub fn identity_center_configuration( self, input: IdentityCenterConfiguration, ) -> Self

Specifies whether the workgroup is IAM Identity Center supported.

pub fn set_identity_center_configuration( self, input: Option<IdentityCenterConfiguration>, ) -> Self

Specifies whether the workgroup is IAM Identity Center supported.

pub fn get_identity_center_configuration( &self, ) -> &Option<IdentityCenterConfiguration>

Specifies whether the workgroup is IAM Identity Center supported.

pub fn query_results_s3_access_grants_configuration( self, input: QueryResultsS3AccessGrantsConfiguration, ) -> Self

Specifies whether Amazon S3 access grants are enabled for query results.

pub fn set_query_results_s3_access_grants_configuration( self, input: Option<QueryResultsS3AccessGrantsConfiguration>, ) -> Self

Specifies whether Amazon S3 access grants are enabled for query results.

pub fn get_query_results_s3_access_grants_configuration( &self, ) -> &Option<QueryResultsS3AccessGrantsConfiguration>

Specifies whether Amazon S3 access grants are enabled for query results.

pub fn build(self) -> WorkGroupConfiguration

Consumes the builder and constructs a WorkGroupConfiguration.