#[non_exhaustive]pub struct WorkGroupSummaryBuilder { /* private fields */ }Expand description
A builder for WorkGroupSummary.
Implementations
Sourceimpl WorkGroupSummaryBuilder
impl WorkGroupSummaryBuilder
Sourcepub fn state(self, input: WorkGroupState) -> Self
pub fn state(self, input: WorkGroupState) -> Self
The state of the workgroup.
Sourcepub fn set_state(self, input: Option<WorkGroupState>) -> Self
pub fn set_state(self, input: Option<WorkGroupState>) -> Self
The state of the workgroup.
Sourcepub fn get_state(&self) -> &Option<WorkGroupState>
pub fn get_state(&self) -> &Option<WorkGroupState>
The state of the workgroup.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The workgroup description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The workgroup description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The workgroup description.
Sourcepub fn creation_time(self, input: DateTime) -> Self
pub fn creation_time(self, input: DateTime) -> Self
The workgroup creation date and time.
Sourcepub fn set_creation_time(self, input: Option<DateTime>) -> Self
pub fn set_creation_time(self, input: Option<DateTime>) -> Self
The workgroup creation date and time.
Sourcepub fn get_creation_time(&self) -> &Option<DateTime>
pub fn get_creation_time(&self) -> &Option<DateTime>
The workgroup creation date and time.
Sourcepub fn engine_version(self, input: EngineVersion) -> Self
pub fn engine_version(self, input: EngineVersion) -> Self
The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn set_engine_version(self, input: Option<EngineVersion>) -> Self
pub fn set_engine_version(self, input: Option<EngineVersion>) -> Self
The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn get_engine_version(&self) -> &Option<EngineVersion>
pub fn get_engine_version(&self) -> &Option<EngineVersion>
The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn identity_center_application_arn(self, input: impl Into<String>) -> Self
pub fn identity_center_application_arn(self, input: impl Into<String>) -> Self
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourcepub fn set_identity_center_application_arn(self, input: Option<String>) -> Self
pub fn set_identity_center_application_arn(self, input: Option<String>) -> Self
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourcepub fn get_identity_center_application_arn(&self) -> &Option<String>
pub fn get_identity_center_application_arn(&self) -> &Option<String>
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourcepub fn build(self) -> WorkGroupSummary
pub fn build(self) -> WorkGroupSummary
Consumes the builder and constructs a WorkGroupSummary.