#[non_exhaustive]pub struct ExecutorsSummaryBuilder { /* private fields */ }Expand description
A builder for ExecutorsSummary.
Implementations
Sourceimpl ExecutorsSummaryBuilder
impl ExecutorsSummaryBuilder
Sourcepub fn executor_id(self, input: impl Into<String>) -> Self
pub fn executor_id(self, input: impl Into<String>) -> Self
The UUID of the executor.
This field is required.Sourcepub fn set_executor_id(self, input: Option<String>) -> Self
pub fn set_executor_id(self, input: Option<String>) -> Self
The UUID of the executor.
Sourcepub fn get_executor_id(&self) -> &Option<String>
pub fn get_executor_id(&self) -> &Option<String>
The UUID of the executor.
Sourcepub fn executor_type(self, input: ExecutorType) -> Self
pub fn executor_type(self, input: ExecutorType) -> Self
The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).
Sourcepub fn set_executor_type(self, input: Option<ExecutorType>) -> Self
pub fn set_executor_type(self, input: Option<ExecutorType>) -> Self
The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).
Sourcepub fn get_executor_type(&self) -> &Option<ExecutorType>
pub fn get_executor_type(&self) -> &Option<ExecutorType>
The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).
Sourcepub fn start_date_time(self, input: i64) -> Self
pub fn start_date_time(self, input: i64) -> Self
The date and time that the executor started.
Sourcepub fn set_start_date_time(self, input: Option<i64>) -> Self
pub fn set_start_date_time(self, input: Option<i64>) -> Self
The date and time that the executor started.
Sourcepub fn get_start_date_time(&self) -> &Option<i64>
pub fn get_start_date_time(&self) -> &Option<i64>
The date and time that the executor started.
Sourcepub fn termination_date_time(self, input: i64) -> Self
pub fn termination_date_time(self, input: i64) -> Self
The date and time that the executor was terminated.
Sourcepub fn set_termination_date_time(self, input: Option<i64>) -> Self
pub fn set_termination_date_time(self, input: Option<i64>) -> Self
The date and time that the executor was terminated.
Sourcepub fn get_termination_date_time(&self) -> &Option<i64>
pub fn get_termination_date_time(&self) -> &Option<i64>
The date and time that the executor was terminated.
Sourcepub fn executor_state(self, input: ExecutorState) -> Self
pub fn executor_state(self, input: ExecutorState) -> Self
The processing state of the executor. A description of each state follows.
CREATING - The executor is being started, including acquiring resources.
CREATED - The executor has been started.
REGISTERED - The executor has been registered.
TERMINATING - The executor is in the process of shutting down.
TERMINATED - The executor is no longer running.
FAILED - Due to a failure, the executor is no longer running.
Sourcepub fn set_executor_state(self, input: Option<ExecutorState>) -> Self
pub fn set_executor_state(self, input: Option<ExecutorState>) -> Self
The processing state of the executor. A description of each state follows.
CREATING - The executor is being started, including acquiring resources.
CREATED - The executor has been started.
REGISTERED - The executor has been registered.
TERMINATING - The executor is in the process of shutting down.
TERMINATED - The executor is no longer running.
FAILED - Due to a failure, the executor is no longer running.
Sourcepub fn get_executor_state(&self) -> &Option<ExecutorState>
pub fn get_executor_state(&self) -> &Option<ExecutorState>
The processing state of the executor. A description of each state follows.
CREATING - The executor is being started, including acquiring resources.
CREATED - The executor has been started.
REGISTERED - The executor has been registered.
TERMINATING - The executor is in the process of shutting down.
TERMINATED - The executor is no longer running.
FAILED - Due to a failure, the executor is no longer running.
Sourcepub fn executor_size(self, input: i64) -> Self
pub fn executor_size(self, input: i64) -> Self
The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.
Sourcepub fn set_executor_size(self, input: Option<i64>) -> Self
pub fn set_executor_size(self, input: Option<i64>) -> Self
The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.
Sourcepub fn get_executor_size(&self) -> &Option<i64>
pub fn get_executor_size(&self) -> &Option<i64>
The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.
Sourcepub fn build(self) -> Result<ExecutorsSummary, BuildError>
pub fn build(self) -> Result<ExecutorsSummary, BuildError>
Consumes the builder and constructs a ExecutorsSummary.
This method will fail if any of the following fields are not set: