#[non_exhaustive]pub struct WorkGroupBuilder { /* private fields */ }Expand description
A builder for WorkGroup.
Implementations
Sourceimpl WorkGroupBuilder
impl WorkGroupBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The workgroup name.
This field is required.Sourcepub fn state(self, input: WorkGroupState) -> Self
pub fn state(self, input: WorkGroupState) -> Self
The state of the workgroup: ENABLED or DISABLED.
Sourcepub fn set_state(self, input: Option<WorkGroupState>) -> Self
pub fn set_state(self, input: Option<WorkGroupState>) -> Self
The state of the workgroup: ENABLED or DISABLED.
Sourcepub fn get_state(&self) -> &Option<WorkGroupState>
pub fn get_state(&self) -> &Option<WorkGroupState>
The state of the workgroup: ENABLED or DISABLED.
Sourcepub fn configuration(self, input: WorkGroupConfiguration) -> Self
pub fn configuration(self, input: WorkGroupConfiguration) -> Self
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
Sourcepub fn set_configuration(self, input: Option<WorkGroupConfiguration>) -> Self
pub fn set_configuration(self, input: Option<WorkGroupConfiguration>) -> Self
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
Sourcepub fn get_configuration(&self) -> &Option<WorkGroupConfiguration>
pub fn get_configuration(&self) -> &Option<WorkGroupConfiguration>
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The workgroup description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The workgroup description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The workgroup description.
Sourcepub fn creation_time(self, input: DateTime) -> Self
pub fn creation_time(self, input: DateTime) -> Self
The date and time the workgroup was created.
Sourcepub fn set_creation_time(self, input: Option<DateTime>) -> Self
pub fn set_creation_time(self, input: Option<DateTime>) -> Self
The date and time the workgroup was created.
Sourcepub fn get_creation_time(&self) -> &Option<DateTime>
pub fn get_creation_time(&self) -> &Option<DateTime>
The date and time the workgroup was created.
Sourcepub fn identity_center_application_arn(self, input: impl Into<String>) -> Self
pub fn identity_center_application_arn(self, input: impl Into<String>) -> Self
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourcepub fn set_identity_center_application_arn(self, input: Option<String>) -> Self
pub fn set_identity_center_application_arn(self, input: Option<String>) -> Self
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourcepub fn get_identity_center_application_arn(&self) -> &Option<String>
pub fn get_identity_center_application_arn(&self) -> &Option<String>
The ARN of the IAM Identity Center enabled application associated with the workgroup.