#[non_exhaustive]pub struct WorkGroupConfigurationUpdatesBuilder { /* private fields */ }Expand description
A builder for WorkGroupConfigurationUpdates.
Implementations
Sourceimpl WorkGroupConfigurationUpdatesBuilder
impl WorkGroupConfigurationUpdatesBuilder
Sourcepub fn enforce_work_group_configuration(self, input: bool) -> Self
pub fn enforce_work_group_configuration(self, input: bool) -> Self
If set to "true", the settings for the workgroup override client-side settings. If set to "false" client-side settings are used. For more information, see Workgroup Settings Override Client-Side Settings.
Sourcepub fn set_enforce_work_group_configuration(self, input: Option<bool>) -> Self
pub fn set_enforce_work_group_configuration(self, input: Option<bool>) -> Self
If set to "true", the settings for the workgroup override client-side settings. If set to "false" client-side settings are used. For more information, see Workgroup Settings Override Client-Side Settings.
Sourcepub fn get_enforce_work_group_configuration(&self) -> &Option<bool>
pub fn get_enforce_work_group_configuration(&self) -> &Option<bool>
If set to "true", the settings for the workgroup override client-side settings. If set to "false" client-side settings are used. For more information, see Workgroup Settings Override Client-Side Settings.
Sourcepub fn result_configuration_updates(
self,
input: ResultConfigurationUpdates,
) -> Self
pub fn result_configuration_updates( self, input: ResultConfigurationUpdates, ) -> Self
The result configuration information about the queries in this workgroup that will be updated. Includes the updated results location and an updated option for encrypting query results.
Sourcepub fn set_result_configuration_updates(
self,
input: Option<ResultConfigurationUpdates>,
) -> Self
pub fn set_result_configuration_updates( self, input: Option<ResultConfigurationUpdates>, ) -> Self
The result configuration information about the queries in this workgroup that will be updated. Includes the updated results location and an updated option for encrypting query results.
Sourcepub fn get_result_configuration_updates(
&self,
) -> &Option<ResultConfigurationUpdates>
pub fn get_result_configuration_updates( &self, ) -> &Option<ResultConfigurationUpdates>
The result configuration information about the queries in this workgroup that will be updated. Includes the updated results location and an updated option for encrypting query results.
Sourcepub fn managed_query_results_configuration_updates(
self,
input: ManagedQueryResultsConfigurationUpdates,
) -> Self
pub fn managed_query_results_configuration_updates( self, input: ManagedQueryResultsConfigurationUpdates, ) -> Self
Updates configuration information for managed query results in the workgroup.
Sourcepub fn set_managed_query_results_configuration_updates(
self,
input: Option<ManagedQueryResultsConfigurationUpdates>,
) -> Self
pub fn set_managed_query_results_configuration_updates( self, input: Option<ManagedQueryResultsConfigurationUpdates>, ) -> Self
Updates configuration information for managed query results in the workgroup.
Sourcepub fn get_managed_query_results_configuration_updates(
&self,
) -> &Option<ManagedQueryResultsConfigurationUpdates>
pub fn get_managed_query_results_configuration_updates( &self, ) -> &Option<ManagedQueryResultsConfigurationUpdates>
Updates configuration information for managed query results in the workgroup.
Sourcepub fn publish_cloud_watch_metrics_enabled(self, input: bool) -> Self
pub fn publish_cloud_watch_metrics_enabled(self, input: bool) -> Self
Indicates whether this workgroup enables publishing metrics to Amazon CloudWatch.
Sourcepub fn set_publish_cloud_watch_metrics_enabled(
self,
input: Option<bool>,
) -> Self
pub fn set_publish_cloud_watch_metrics_enabled( self, input: Option<bool>, ) -> Self
Indicates whether this workgroup enables publishing metrics to Amazon CloudWatch.
Sourcepub fn get_publish_cloud_watch_metrics_enabled(&self) -> &Option<bool>
pub fn get_publish_cloud_watch_metrics_enabled(&self) -> &Option<bool>
Indicates whether this workgroup enables publishing metrics to Amazon CloudWatch.
Sourcepub fn bytes_scanned_cutoff_per_query(self, input: i64) -> Self
pub fn bytes_scanned_cutoff_per_query(self, input: i64) -> Self
The upper limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.
Sourcepub fn set_bytes_scanned_cutoff_per_query(self, input: Option<i64>) -> Self
pub fn set_bytes_scanned_cutoff_per_query(self, input: Option<i64>) -> Self
The upper limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.
Sourcepub fn get_bytes_scanned_cutoff_per_query(&self) -> &Option<i64>
pub fn get_bytes_scanned_cutoff_per_query(&self) -> &Option<i64>
The upper limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.
Sourcepub fn remove_bytes_scanned_cutoff_per_query(self, input: bool) -> Self
pub fn remove_bytes_scanned_cutoff_per_query(self, input: bool) -> Self
Indicates that the data usage control limit per query is removed. WorkGroupConfiguration$BytesScannedCutoffPerQuery
Sourcepub fn set_remove_bytes_scanned_cutoff_per_query(
self,
input: Option<bool>,
) -> Self
pub fn set_remove_bytes_scanned_cutoff_per_query( self, input: Option<bool>, ) -> Self
Indicates that the data usage control limit per query is removed. WorkGroupConfiguration$BytesScannedCutoffPerQuery
Sourcepub fn get_remove_bytes_scanned_cutoff_per_query(&self) -> &Option<bool>
pub fn get_remove_bytes_scanned_cutoff_per_query(&self) -> &Option<bool>
Indicates that the data usage control limit per query is removed. WorkGroupConfiguration$BytesScannedCutoffPerQuery
Sourcepub fn requester_pays_enabled(self, input: bool) -> Self
pub fn requester_pays_enabled(self, input: bool) -> Self
If set to true, allows members assigned to a workgroup to specify Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.
Sourcepub fn set_requester_pays_enabled(self, input: Option<bool>) -> Self
pub fn set_requester_pays_enabled(self, input: Option<bool>) -> Self
If set to true, allows members assigned to a workgroup to specify Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.
Sourcepub fn get_requester_pays_enabled(&self) -> &Option<bool>
pub fn get_requester_pays_enabled(&self) -> &Option<bool>
If set to true, allows members assigned to a workgroup to specify Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see Requester Pays Buckets in the Amazon Simple Storage Service Developer Guide.
Sourcepub fn engine_version(self, input: EngineVersion) -> Self
pub fn engine_version(self, input: EngineVersion) -> Self
The engine version requested when a workgroup is updated. After the update, all queries on the workgroup run on the requested engine version. If no value was previously set, the default is Auto. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn set_engine_version(self, input: Option<EngineVersion>) -> Self
pub fn set_engine_version(self, input: Option<EngineVersion>) -> Self
The engine version requested when a workgroup is updated. After the update, all queries on the workgroup run on the requested engine version. If no value was previously set, the default is Auto. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn get_engine_version(&self) -> &Option<EngineVersion>
pub fn get_engine_version(&self) -> &Option<EngineVersion>
The engine version requested when a workgroup is updated. After the update, all queries on the workgroup run on the requested engine version. If no value was previously set, the default is Auto. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn remove_customer_content_encryption_configuration(
self,
input: bool,
) -> Self
pub fn remove_customer_content_encryption_configuration( self, input: bool, ) -> Self
Removes content encryption configuration from an Apache Spark-enabled Athena workgroup.
Sourcepub fn set_remove_customer_content_encryption_configuration(
self,
input: Option<bool>,
) -> Self
pub fn set_remove_customer_content_encryption_configuration( self, input: Option<bool>, ) -> Self
Removes content encryption configuration from an Apache Spark-enabled Athena workgroup.
Sourcepub fn get_remove_customer_content_encryption_configuration(
&self,
) -> &Option<bool>
pub fn get_remove_customer_content_encryption_configuration( &self, ) -> &Option<bool>
Removes content encryption configuration from an Apache Spark-enabled Athena workgroup.
Sourcepub fn additional_configuration(self, input: impl Into<String>) -> Self
pub fn additional_configuration(self, input: impl Into<String>) -> Self
Contains a user defined string in JSON format for a Spark-enabled workgroup.
Sourcepub fn set_additional_configuration(self, input: Option<String>) -> Self
pub fn set_additional_configuration(self, input: Option<String>) -> Self
Contains a user defined string in JSON format for a Spark-enabled workgroup.
Sourcepub fn get_additional_configuration(&self) -> &Option<String>
pub fn get_additional_configuration(&self) -> &Option<String>
Contains a user defined string in JSON format for a Spark-enabled workgroup.
Sourcepub fn execution_role(self, input: impl Into<String>) -> Self
pub fn execution_role(self, input: impl Into<String>) -> Self
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn set_execution_role(self, input: Option<String>) -> Self
pub fn set_execution_role(self, input: Option<String>) -> Self
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn get_execution_role(&self) -> &Option<String>
pub fn get_execution_role(&self) -> &Option<String>
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn customer_content_encryption_configuration(
self,
input: CustomerContentEncryptionConfiguration,
) -> Self
pub fn customer_content_encryption_configuration( self, input: CustomerContentEncryptionConfiguration, ) -> Self
Specifies the customer managed KMS key that is used to encrypt the user's data stores in Athena. When an Amazon Web Services managed key is used, this value is null. This setting does not apply to Athena SQL workgroups.
Sourcepub fn set_customer_content_encryption_configuration(
self,
input: Option<CustomerContentEncryptionConfiguration>,
) -> Self
pub fn set_customer_content_encryption_configuration( self, input: Option<CustomerContentEncryptionConfiguration>, ) -> Self
Specifies the customer managed KMS key that is used to encrypt the user's data stores in Athena. When an Amazon Web Services managed key is used, this value is null. This setting does not apply to Athena SQL workgroups.
Sourcepub fn get_customer_content_encryption_configuration(
&self,
) -> &Option<CustomerContentEncryptionConfiguration>
pub fn get_customer_content_encryption_configuration( &self, ) -> &Option<CustomerContentEncryptionConfiguration>
Specifies the customer managed KMS key that is used to encrypt the user's data stores in Athena. When an Amazon Web Services managed key is used, this value is null. This setting does not apply to Athena SQL workgroups.
Sourcepub fn enable_minimum_encryption_configuration(self, input: bool) -> Self
pub fn enable_minimum_encryption_configuration(self, input: bool) -> Self
Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries. This setting does not apply to Spark-enabled workgroups.
The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.
Sourcepub fn set_enable_minimum_encryption_configuration(
self,
input: Option<bool>,
) -> Self
pub fn set_enable_minimum_encryption_configuration( self, input: Option<bool>, ) -> Self
Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries. This setting does not apply to Spark-enabled workgroups.
The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.
Sourcepub fn get_enable_minimum_encryption_configuration(&self) -> &Option<bool>
pub fn get_enable_minimum_encryption_configuration(&self) -> &Option<bool>
Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries. This setting does not apply to Spark-enabled workgroups.
The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.
Sourcepub fn query_results_s3_access_grants_configuration(
self,
input: QueryResultsS3AccessGrantsConfiguration,
) -> Self
pub fn query_results_s3_access_grants_configuration( self, input: QueryResultsS3AccessGrantsConfiguration, ) -> Self
Specifies whether Amazon S3 access grants are enabled for query results.
Sourcepub fn set_query_results_s3_access_grants_configuration(
self,
input: Option<QueryResultsS3AccessGrantsConfiguration>,
) -> Self
pub fn set_query_results_s3_access_grants_configuration( self, input: Option<QueryResultsS3AccessGrantsConfiguration>, ) -> Self
Specifies whether Amazon S3 access grants are enabled for query results.
Sourcepub fn get_query_results_s3_access_grants_configuration(
&self,
) -> &Option<QueryResultsS3AccessGrantsConfiguration>
pub fn get_query_results_s3_access_grants_configuration( &self, ) -> &Option<QueryResultsS3AccessGrantsConfiguration>
Specifies whether Amazon S3 access grants are enabled for query results.
Sourcepub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
pub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn set_monitoring_configuration(
self,
input: Option<MonitoringConfiguration>,
) -> Self
pub fn set_monitoring_configuration( self, input: Option<MonitoringConfiguration>, ) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
pub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn engine_configuration(self, input: EngineConfiguration) -> Self
pub fn engine_configuration(self, input: EngineConfiguration) -> Self
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).
To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.
Sourcepub fn set_engine_configuration(
self,
input: Option<EngineConfiguration>,
) -> Self
pub fn set_engine_configuration( self, input: Option<EngineConfiguration>, ) -> Self
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).
To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.
Sourcepub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
pub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).
To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.
Sourcepub fn build(self) -> WorkGroupConfigurationUpdates
pub fn build(self) -> WorkGroupConfigurationUpdates
Consumes the builder and constructs a WorkGroupConfigurationUpdates.